<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>ReminderDialog</name>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="35"/>
        <source>Restart the computer to use the system and the applications properly</source>
        <translation>需要重新啟動才能正常使用系統及應用程式</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="36"/>
        <source>Make sure all data had been saved first</source>
        <translation>請確保已先儲存所有資料</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="44"/>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
</context>
</TS>